/*----------------------------------------------------------------------------

  Point alignment detector (3D)

  This code is part of the following IPOL publication and was subject
  to peer review. If you use it, please cite it as:

   ........................................

  Copyright (c) 2017  Alvaro Gomez  <agomez@fing.edu.uy>,
  Gregory Randall<randall@fing.edu.uy> and Rafael Grompone von Gioi <grompone@gmail.com>.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.

  ----------------------------------------------------------------------------*/

#ifndef POINT_ALIGNMENTS_HEADER
#define POINT_ALIGNMENTS_HEADER

/*----------------------------------------------------------------------------*/
/*
   input:  point          - input points (including extended points at the end)
           N              - number of points
           X,Y,Z          - domain size [0,X] x [0,Y] x [0,Z]
           sectors        - number of sector to divide the local cylinder
           indexOfPoint1  - (for testing a single alignment) index of first point
           indexOfPoint2  - (for testing a single alignment) index of second point

   output: pointer to *Nout 10-tuples
           x1 y1 z1 x2 y2 z2 width local_window_width num_boxes log_nfa

           if local_window_width is zero, no local window
           if num_boxes is zero, no boxes
 */
double * point_alignments(double * point, int N, double X, double Y, double Z,  int *Nout, int sectors, int indexOfPoint1, int indexOfPoint2);


#endif /* !POINT_ALIGNMENTS_HEADER */
/*----------------------------------------------------------------------------*/
