#!/usr/bin/gnuplot
# A Contrario 3D Point Alignment Detection Algorithm 
# by Alvaro Gomez, Rafael Grompone von Gioi, Gregory Randall
# agomez@fing.edu.uy, grompone@gmail.com
# (code fon gnuplot based on example by Hagen Wierstorf)
#
# Plots the points and alignments. Shows in window or saves a png image
# Requires gnuplot 5.0
#
# Usage:
#  gnuplot -c show_output.gp [points_filename alignments_filename] [optional: show (default) or save]
#
#
# examples:
#     gnuplot -c show_output.gp points.txt alignments.txt 
#     gnuplot -c show_output.gp points.txt alignments.txt save
#     gnuplot -c show_output.gp				-> uses default files points.txt, output.txt
#     gnuplot -c show_output.gp save			-> uses default files points.txt, output.txt   
#

points_filename = "points.txt"
output_filename = "output.txt"
action = "show"
if (ARGC >= 2){
	points_filename = ARG1
	output_filename = ARG2
}
if (ARGC == 3){
	action = ARG3
}
if (ARGC == 1){
	action = ARG1
}

reset

if(action eq "show"){
# wxt
set terminal wxt size 800,600 enhanced font 'Verdana,10' persist
}
else{
# save a png
set terminal pngcairo size 800,600 enhanced font 'Verdana,10'
set output 'output.png'
}

# color definitions
set border linewidth 1.5
set style line 1 lc rgb '#0060ad' lt 1 lw 0.5 pt 7 ps 0.5  # --- blue points
set style line 2 lc rgb '#ad6000' lt 1 lw 1   pt 7 ps 0.5  # --- red points, orange line
set style line 3 lc rgb '#aacc6000' lt 1 lw 5   pt 7 ps 0.5  # --- wide semi-transparent line (alpha requires gnuplot>=5.0)
set style line 4 lc rgb '#cc6000' lt 1 lw 2   pt 7 ps 0.5  # --- narrow orange line 

set style arrow 1 nohead ls 3
 
unset key

#set xtics 0.2
#set ytics 0.2
#set ztics 0.2

set tics scale 0.5
set ticslevel 0       #move zero of zaxis to the xy plane

set xrange [-0.2:1.2]
set yrange [-0.2:1.2]
set zrange [-0.2:1.2]

set view equal xyz

splot (points_filename) with points linestyle 1, \
      (output_filename) using 1:2:3:($4-$1):($5-$2):($6-$3) with vector arrowstyle 1, \
      (output_filename) using 1:2:3:(sprintf("logNFA=%.2f",$10)) with labels left

